tiled.adapters.hdf5.HDF5Adapter
===============================

.. currentmodule:: tiled.adapters.hdf5

.. autoclass:: HDF5Adapter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HDF5Adapter.__init__
      ~HDF5Adapter.authenticated_as
      ~HDF5Adapter.from_file
      ~HDF5Adapter.get
      ~HDF5Adapter.items
      ~HDF5Adapter.keys
      ~HDF5Adapter.read
      ~HDF5Adapter.search
      ~HDF5Adapter.values
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~HDF5Adapter.access_policy
      ~HDF5Adapter.items_indexer
      ~HDF5Adapter.keys_indexer
      ~HDF5Adapter.metadata
      ~HDF5Adapter.principal
      ~HDF5Adapter.structure_family
      ~HDF5Adapter.values_indexer
   
   